@@ -9,7 +9,7 @@
 
 using namespace Qt::Literals::StringLiterals;
 
-QByteArray readMailFromFile(const QString &mailFile)
+static QByteArray readMailFromFile(const QString &mailFile)
 {
     QFile file(QLatin1StringView(MAIL_DATA_DIR) + QLatin1Char('/') + mailFile);
     file.open(QIODevice::ReadOnly);
